aboutsummaryrefslogtreecommitdiffstats
path: root/tests/conftest.py
diff options
context:
space:
mode:
authorAlex Stapleton <alexs@prol.etari.at>2014-04-22 08:54:55 +0100
committerAlex Stapleton <alexs@prol.etari.at>2014-04-22 08:54:55 +0100
commitb5236fe24efa4d399353327db49c23dc6e81d1f5 (patch)
treee2f9e10253aa11abf3db77ea5613f7e5daab47b5 /tests/conftest.py
parenta33dd28e1b4412695bc72ba1c888ca616852eac6 (diff)
parent9a97cb93205b5785423bac9cae9288310f3b0c5a (diff)
downloadcryptography-b5236fe24efa4d399353327db49c23dc6e81d1f5.tar.gz
cryptography-b5236fe24efa4d399353327db49c23dc6e81d1f5.tar.bz2
cryptography-b5236fe24efa4d399353327db49c23dc6e81d1f5.zip
Merge pull request #931 from Ayrx/cmac-implementation
CMAC implementation and docs
Diffstat (limited to 'tests/conftest.py')
-rw-r--r--tests/conftest.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/conftest.py b/tests/conftest.py
index 1ee2a993..d55e6cf6 100644
--- a/tests/conftest.py
+++ b/tests/conftest.py
@@ -17,10 +17,9 @@ import pytest
from cryptography.hazmat.backends import _available_backends
from cryptography.hazmat.backends.interfaces import (
- CipherBackend, DSABackend, HMACBackend, HashBackend, PBKDF2HMACBackend,
- RSABackend
+ CMACBackend, CipherBackend, DSABackend, HMACBackend, HashBackend,
+ PBKDF2HMACBackend, RSABackend
)
-
from .utils import check_backend_support, check_for_iface, select_backends
@@ -36,6 +35,7 @@ def pytest_generate_tests(metafunc):
def pytest_runtest_setup(item):
check_for_iface("hmac", HMACBackend, item)
check_for_iface("cipher", CipherBackend, item)
+ check_for_iface("cmac", CMACBackend, item)
check_for_iface("hash", HashBackend, item)
check_for_iface("pbkdf2hmac", PBKDF2HMACBackend, item)
check_for_iface("dsa", DSABackend, item)